@@ -152,6 +152,7 @@ sub stringify_column {
     my $class = shift;
     return (
         $class->columns("Stringify"),
+        ( grep { /^(name|title)$/i } $class->columns ),
         ( grep { /(name|title)/i } $class->columns ),
         ( grep { !/id$/i } $class->primary_columns ),
     )[0];
@@ -202,12 +203,12 @@ sub do_pager {
 
 sub order {
     my ( $self, $r ) = @_;
-    my $order;
     my %ok_columns = map { $_ => 1 } $self->columns;
-    if ( $order = $r->query->{order} and $ok_columns{$order} ) {
-        $order .= ( $r->query->{o2} eq "desc" && " DESC" );
-    }
-    $order;
+    my $q = $r->query;
+    my $order = $q->{order};
+    return unless $order and $ok_columns{$order};
+    $order .= ' DESC' if $q->{o2} and $q->{o2} eq 'desc';
+    return $order;
 }
 
 sub list : Exported {
@@ -236,7 +237,7 @@ sub setup_database {
             dsn       => $dsn,
             user      => $u,
             password  => $p,
-            options   => $opts,
+	    %$opts,
         )
     );
     $config->{classes} = [ $config->{loader}->classes ];
